@@ -40,7 +40,7 @@ checkX <- function(x) {
 #' @noRd
 checkCdm <- function(cdm, tables = NULL) {
   if (!isTRUE(inherits(cdm, "cdm_reference"))) {
-    cli::cli_abort("cdm must be a CDMConnector CDM reference object")
+    cli::cli_abort("cdm a cdm_reference object.")
   }
   if (!is.null(tables)) {
     tables <- tables[!(tables %in% names(cdm))]
@@ -48,7 +48,7 @@ checkCdm <- function(cdm, tables = NULL) {
       cli::cli_abort(paste0(
         "tables: ",
         paste0(tables, collapse = ", "),
-        "are not present in the cdm object"
+        " are not present in the cdm object"
       ))
     }
   }
@@ -111,7 +111,12 @@ checkCategory <- function(category, overlap = FALSE, type = "numeric") {
     dplyr::mutate(category_label = names(.env$category)) %>%
     dplyr::mutate(category_label = dplyr::if_else(
       .data$category_label == "",
-      paste0(.data$lower_bound, " to ", .data$upper_bound),
+      dplyr::case_when(
+        is.infinite(.data$lower_bound) & is.infinite(.data$upper_bound) ~ "any",
+        is.infinite(.data$lower_bound) ~ paste(.data$upper_bound, "or below"),
+        is.infinite(.data$upper_bound) ~ paste(.data$lower_bound, "or above"),
+        TRUE ~ paste(.data$lower_bound, "to", .data$upper_bound)
+      ),
       .data$category_label
     )) %>%
     dplyr::arrange(.data$lower_bound)
@@ -139,6 +144,10 @@ checkAgeGroup <- function(ageGroup, overlap = FALSE) {
     }
     for (k in seq_along(ageGroup)) {
       invisible(checkCategory(ageGroup[[k]], overlap))
+      if (any(ageGroup[[k]] |> unlist() |> unique() < 0)) {
+        cli::cli_abort("ageGroup can't contain negative values")
+      }
+
     }
     if (is.null(names(ageGroup))) {
       names(ageGroup) <- paste0("age_group_", 1:length(ageGroup))
@@ -208,19 +217,13 @@ checkWindow <- function(window) {
 
 #' @noRd
 checkNewName <- function(name, x) {
-  for (k in seq_along(name)) {
-    if (name[k] %in% colnames(x)) {
-      id <- 1
-      newName <- paste0(name[k], "_", id)
-      while (newName %in% colnames(x)) {
-        id <- id + 1
-        newName <- paste0(name[k], "_", id)
-      }
-      warning(glue::glue(
-        "{name[k]} already exists in x, it was renamed to {newName}"
-      ))
-      name[k] <- newName
-    }
+  renamed <- name[name %in% colnames(x)]
+  if (length(renamed) > 0) {
+    mes <- paste0(
+      "The following columns will be overwritten: ",
+      paste0(renamed, collapse = ", ")
+    )
+    cli::cli_warn(message = mes)
   }
   invisible(name)
 }
@@ -312,7 +315,7 @@ checkValue <- function(value, x, name) {
       paste0(valueOptions, collapse = ", "),
       " are also present in ",
       name,
-      ". But have theyr own functionality inside the package. If you want to
+      ". But have their own functionality inside the package. If you want to
       obtain that column please rename and run again."
     ))
   }
@@ -321,14 +324,10 @@ checkValue <- function(value, x, name) {
 
 #' @noRd
 checkCohortNames <- function(x, targetCohortId, name) {
-  if (!("GeneratedCohortSet" %in% class(x))) {
-    cli::cli_abort(
-      "cdm[[targetCohortTable]]) must be a 'GeneratedCohortSet'. Please use a
-      generateCohortSet function or create it with
-      CDMConnector::newGeneratedCohortSet()."
-    )
+  if (!("cohort_table" %in% class(x))) {
+    cli::cli_abort("cdm[[targetCohortTable]]) must be a 'cohort_table'.")
   }
-  cohort <- CDMConnector::cohortSet(x)
+  cohort <- omopgenerics::settings(x)
   filterVariable <- "cohort_definition_id"
   if (is.null(targetCohortId)) {
     if (is.null(cohort)) {
@@ -345,19 +344,23 @@ checkCohortNames <- function(x, targetCohortId, name) {
       idName <- paste0(name, "_", targetCohortId)
     } else {
       idName <- cohort %>%
-        dplyr::filter(.data$cohort_definition_id %in% .env$targetCohortId) %>%
+        dplyr::filter(
+          as.integer(.data$cohort_definition_id) %in%
+            as.integer(.env$targetCohortId)
+        ) %>%
         dplyr::arrange(.data$cohort_definition_id) %>%
         dplyr::pull("cohort_name")
       if (length(idName) != length(targetCohortId)) {
         cli::cli_abort(
-          "some of the cohort ids given do not exist in the cohortSet of cdm[[targetCohortName]]"
+          "some of the cohort ids given do not exist in the cohortSet of
+          cdm[[targetCohortName]]"
         )
       }
     }
   }
   parameters <- list(
     "filter_variable" = filterVariable,
-    "filter_id" = targetCohortId,
+    "filter_id" = sort(targetCohortId),
     "id_name" = idName
   )
   invisible(parameters)
@@ -479,7 +482,8 @@ checkVariablesFunctions <- function(variables, functions, table) {
     dplyr::left_join(
       formats %>%
         dplyr::select("variable_type", "format_key"),
-      by = "variable_type"
+      by = "variable_type",
+      relationship = "many-to-many"
     )
   nonSuportedFunctions <- requiredFunctions %>%
     dplyr::anti_join(suportedFunctions, by = c("variable", "format_key"))
@@ -531,14 +535,19 @@ checkSignificantDecimals <- function(significantDecimals) {
 
 #' @noRd
 checkTableIntersect <- function(tableIntersect, cdm) {
-  checkmate::assertList(tableIntersect, names = "named")
-  arguments <- getArguments(addIntersect)
+  checkmate::assertList(tableIntersect)
+  arguments <- getArguments(addTableIntersect)
+  if (length(tableIntersect) > 0) {
+    if (!is.list(tableIntersect[[1]])) {
+      tableIntersect <- list(tableIntersect)
+    }
+  }
   lapply(tableIntersect, function(x) {
     checkmate::assertList(x, names = "named")
     checkmate::assertTRUE(all(names(x) %in% c(arguments$all, "value")))
     checkmate::assertTRUE(all(arguments$compulsory %in% names(x)))
   })
-  invisible(NULL)
+  return(tableIntersect)
 }
 
 getArguments <- function(fun) {
@@ -557,26 +566,36 @@ getArguments <- function(fun) {
 
 #' @noRd
 checkCohortIntersect <- function(cohortIntersect, cdm) {
-  checkmate::assertList(cohortIntersect, names = "named")
+  checkmate::assertList(cohortIntersect)
   arguments <- getArguments(addCohortIntersect)
+  if (length(cohortIntersect) > 0) {
+    if (!is.list(cohortIntersect[[1]])) {
+      cohortIntersect <- list(cohortIntersect)
+    }
+  }
   lapply(cohortIntersect, function(x) {
     checkmate::assertList(x, names = "named")
     checkmate::assertTRUE(all(names(x) %in% c(arguments$all, "value")))
     checkmate::assertTRUE(all(arguments$compulsory %in% names(x)))
   })
-  invisible(NULL)
+  return(cohortIntersect)
 }
 
 #' @noRd
 checkConceptIntersect <- function(conceptIntersect, cdm) {
   checkmate::assertList(conceptIntersect, names = "named")
   arguments <- getArguments(addConceptIntersect)
+  if (length(conceptIntersect) > 0) {
+    if (!identical(lapply(conceptIntersect, class) |> unlist() |> unname() |> unique(), "list")) {
+      conceptIntersect <- list(conceptIntersect)
+    }
+  }
   lapply(conceptIntersect, function(x) {
     checkmate::assertList(x, names = "named")
     checkmate::assertTRUE(all(names(x) %in% c(arguments$all, "value")))
     checkmate::assertTRUE(all(arguments$compulsory %in% names(x)))
   })
-  invisible(NULL)
+  return(conceptIntersect)
 }
 
 #' @noRd
@@ -591,16 +610,6 @@ checkCensorDate <- function(x, censorDate) {
   }
 }
 
-#' @noRd
-assertWriteSchema <- function(cdm, call = rlang::env_parent()) {
-  if (!("write_schema" %in% names(attributes(cdm)))) {
-    cli::cli_abort(
-      message = "write_schema must be provided in the cdm object to use this function",
-      call = call
-    )
-  }
-}
-
 #' @noRd
 checkOtherVariables <- function(otherVariables, cohort, call = rlang::env_parent()) {
   errorMessage <- "otherVariables must point to columns in cohort."
