@@ -1,42 +1,28 @@
 test_that("check input length and type for each of the arguments", {
-  cdm <-
-    mockPatientProfiles(connectionDetails,
-      seed = 1,
-      patient_size = 5,
-      latest_observation_start_date = "2019-01-01",
-      max_days_to_observation_end = 1,
-      min_days_to_observation_end = 1
-    )
+  cdm <- mockPatientProfiles(connectionDetails)
 
-  expect_error(addPriorObservation("cdm$cohort1", cdm))
+  expect_error(addPriorObservation("cdm$cohort1"))
 
-  expect_error(addPriorObservation(cdm$cohort1, "cdm"))
+  expect_warning(addPriorObservation(cdm$cohort1, "cdm"))
 
-  expect_error(addPriorObservation(cdm$cohort1, cdm, indexDate = "end_date"))
+  expect_error(addPriorObservation(cdm$cohort1, indexDate = "end_date"))
 })
 
 test_that("check condition_occurrence and cohort1 work", {
   # mock data
-  cdm <-
-    mockPatientProfiles(connectionDetails,
-      seed = 1,
-      patient_size = 5,
-      latest_observation_start_date = "2005-01-01",
-      max_days_to_observation_end = 1,
-      min_days_to_observation_end = 1
-    )
+  cdm <- mockPatientProfiles(connectionDetails)
   # check it works with cohort1 table in mockdb
-  expect_true(typeof(cdm$cohort1 %>% addPriorObservation(cdm) %>% dplyr::collect()) == "list")
-  expect_true("prior_observation" %in% colnames(cdm$cohort1 %>% addPriorObservation(cdm)))
+  expect_true(typeof(cdm$cohort1 %>% addPriorObservation() %>% dplyr::collect()) == "list")
+  expect_true("prior_observation" %in% colnames(cdm$cohort1 %>% addPriorObservation()))
   # check it works with condition_occurrence table in mockdb
-  expect_true(typeof(cdm$condition_occurrence %>% addPriorObservation(cdm, indexDate = "condition_start_date") %>% dplyr::collect()) == "list")
-  expect_true("prior_observation" %in% colnames(cdm$condition_occurrence %>% addPriorObservation(cdm, indexDate = "condition_start_date")))
+  expect_true(typeof(cdm$condition_occurrence %>% addPriorObservation(indexDate = "condition_start_date") %>% dplyr::collect()) == "list")
+  expect_true("prior_observation" %in% colnames(cdm$condition_occurrence %>% addPriorObservation(indexDate = "condition_start_date")))
 })
 
 test_that("check working example with cohort1", {
   # create mock tables for testing
   cohort1 <- dplyr::tibble(
-    cohort_definition_id = c("1", "1", "1"),
+    cohort_definition_id = c("1", "2", "3"),
     subject_id = c("1", "2", "3"),
     cohort_start_date = c(
       as.Date("2010-03-03"),
@@ -44,9 +30,9 @@ test_that("check working example with cohort1", {
       as.Date("2010-02-01")
     ),
     cohort_end_date = c(
-      as.Date("2015-01-01"),
-      as.Date("2013-01-01"),
-      as.Date("2013-01-01")
+      as.Date("2011-01-01"),
+      as.Date("2011-01-01"),
+      as.Date("2011-01-01")
     )
   )
 
@@ -62,18 +48,19 @@ test_that("check working example with cohort1", {
       as.Date("2014-01-01"),
       as.Date("2012-01-01"),
       as.Date("2012-01-01")
-    )
+    ),
+    period_type_concept_id = 0
   )
 
   cdm <-
     mockPatientProfiles(connectionDetails,
       seed = 1,
       cohort1 = cohort1,
-      observation_period = obs1
+      observation_period = obs1, cohort2 = cohort1
     )
 
   result <- cdm$cohort1 %>%
-    addPriorObservation(cdm) %>%
+    addPriorObservation() %>%
     dplyr::collect()
 
   expect_true(all(colnames(cohort1) %in% colnames(result)))
@@ -95,7 +82,9 @@ test_that("check working example with condition_occurrence", {
       as.Date("2015-01-01"),
       as.Date("2013-01-01"),
       as.Date("2013-01-01")
-    )
+    ),
+    condition_concept_id = 0,
+    condition_type_concept_id = 0
   )
 
   obs1 <- dplyr::tibble(
@@ -110,19 +99,20 @@ test_that("check working example with condition_occurrence", {
       as.Date("2014-01-01"),
       as.Date("2012-01-01"),
       as.Date("2012-01-01")
-    )
+    ),
+    period_type_concept_id = 0
   )
 
   cdm <-
     mockPatientProfiles(connectionDetails,
       seed = 1,
       condition_occurrence = condition_occurrence,
-      observation_period = obs1
+      observation_period = obs1, cohort1 = emptyCohort, cohort2 = emptyCohort
     )
 
   result <-
     cdm$condition_occurrence %>%
-    addPriorObservation(cdm, indexDate = "condition_start_date") %>%
+    addPriorObservation(indexDate = "condition_start_date") %>%
     dplyr::collect()
 
   expect_true(all(
@@ -144,7 +134,9 @@ test_that("different name", {
       as.Date("2015-01-01"),
       as.Date("2013-01-01"),
       as.Date("2013-01-01")
-    )
+    ),
+    condition_concept_id = 0,
+    condition_type_concept_id = 0
   )
 
   obs1 <- dplyr::tibble(
@@ -159,68 +151,26 @@ test_that("different name", {
       as.Date("2014-01-01"),
       as.Date("2012-01-01"),
       as.Date("2012-01-01")
-    )
+    ),
+    period_type_concept_id = 0
   )
 
   cdm <-
     mockPatientProfiles(connectionDetails,
       seed = 1,
       condition_occurrence = conditionOccurrence,
-      observation_period = obs1
+      observation_period = obs1, cohort1 = emptyCohort, cohort2 = emptyCohort
     )
 
   cdm$condition_occurrence <-
     cdm$condition_occurrence %>%
-    addPriorObservation(cdm,
+    addPriorObservation(
       indexDate = "condition_start_date",
       priorObservationName = "ph"
     )
   expect_true("ph" %in% colnames(cdm$condition_occurrence))
 })
 
-test_that("priorHistory and future_observation - outside of observation period", {
-  # priorHistory should be NA if index date is outside of an observation period
-
-  person <- dplyr::tibble(
-    person_id = c(1, 2),
-    gender_concept_id = 1,
-    year_of_birth = 1980,
-    month_of_birth = 01,
-    day_of_birth = 01
-  )
-  observation_period <- dplyr::tibble(
-    observation_period_id = c(1, 2),
-    person_id = c(1, 2),
-    observation_period_start_date = c(
-      as.Date("2000-01-01"),
-      as.Date("2014-01-01")
-    ),
-    observation_period_end_date = c(
-      as.Date("2001-01-01"),
-      as.Date("2015-01-01")
-    )
-  )
-  cohort1 <- dplyr::tibble(
-    cohort_definition_id = 1,
-    subject_id = c(1, 2),
-    cohort_start_date = as.Date(c("2012-02-01")),
-    cohort_end_date = as.Date(c("2013-02-01"))
-  )
-
-  cdm <- mockPatientProfiles(connectionDetails,
-    person = person,
-    observation_period = observation_period,
-    cohort1 = cohort1
-  )
-
-  cdm$cohort1a <- cdm$cohort1 %>%
-    addPriorObservation(cdm,
-      indexDate = "cohort_start_date"
-    )
-  # both should be NA
-  expect_true(all(is.na(cdm$cohort1a %>% dplyr::pull(prior_observation))))
-})
-
 test_that("multiple observation periods", {
   # with multiple observation periods,
   # prior history should relate to the most recent observation start date
@@ -230,7 +180,9 @@ test_that("multiple observation periods", {
     gender_concept_id = 1,
     year_of_birth = 1980,
     month_of_birth = 01,
-    day_of_birth = 01
+    day_of_birth = 01,
+    race_concept_id = 0,
+    ethnicity_concept_id = 0
   )
   observation_period <- dplyr::tibble(
     observation_period_id = c(1, 2, 3),
@@ -244,7 +196,8 @@ test_that("multiple observation periods", {
       as.Date("2005-01-01"),
       as.Date("2015-01-01"),
       as.Date("2015-01-01")
-    )
+    ),
+    period_type_concept_id = 0
   )
   cohort1 <- dplyr::tibble(
     cohort_definition_id = 1,
@@ -256,11 +209,11 @@ test_that("multiple observation periods", {
   cdm <- mockPatientProfiles(connectionDetails,
     person = person,
     observation_period = observation_period,
-    cohort1 = cohort1
+    cohort1 = cohort1, cohort2 = emptyCohort
   )
 
   cdm$cohort1a <- cdm$cohort1 %>%
-    addPriorObservation(cdm,
+    addPriorObservation(
       indexDate = "cohort_start_date"
     )
 
